# sudoh

A simple CLI tool to rerun your last shell command with `sudo`.

## Usage

If you run a command and get an access denied error, just type:

```
sudoh
```

It will rerun your last command with `sudo` prepended.

Supports bash and zsh.
